==> SyL-0.14.8.tar.gz: SyL/include/lib/Xml/Rss/SyL_XmlRssClient.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * HTTP饤ȥ饹
 */
require_once dirname(__FILE__) . '/../../Http/SyL_HttpClient.php';

/**
 * RSS 饤ȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssClient extends SyL_HttpClient
{
    /**
     * RSSС
     * 
     * @access private
     * @var string
     */
    var $rss_version = '';

    /**
     * RSSС򥻥å
     * 
     * @access public
     * @param string RSSС
     */
    function setVersion($rss_version)
    {
        $this->rss_version = $rss_version;
    }

    /**
     * ̥֥Ȥ
     * 
     * @access public
     * @param string 쥹ݥ󥹥ǡ
     * @param string 饤ȥ󥳡
     * @param string RSSС
     */
    function &createResult(&$data, $client_encode='')
    {
        include_once 'SyL_XmlRssClientResult.php';
        $result =& new SyL_XmlRssClientResult($data, $client_encode, $this->rss_version);
        return $result;
    }

}

?>

==> SyL-0.14.9.tar.gz: SyL/include/lib/Xml/Rss/SyL_XmlRssClient.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.4 2008/02/02 14:40:44 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * HTTP饤ȥ饹
 */
require_once dirname(__FILE__) . '/../../Http/SyL_HttpClient.php';
/**
 * RSS饤ȥ쥹ݥ󥹥饹
 */
require_once 'SyL_XmlRssClientResponse.php';

/**
 * RSS饤ȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.4 2008/02/02 14:40:44 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssClient extends SyL_HttpClient
{
    /**
     * RSSС
     * 
     * @access private
     * @var string
     */
    var $rss_version = '';

    /**
     * RSSС򥻥å
     * 
     * @access public
     * @param string RSSС
     */
    function setVersion($rss_version)
    {
        $this->rss_version = $rss_version;
    }

    /**
     * ̥֥Ȥ
     * 
     * @access public
     * @param string 쥹ݥ󥹥ǡ
     * @param string 饤ȥ󥳡
     * @param string RSSС
     */
    function &createResponse(&$data, $client_encode='')
    {
        $response &= new SyL_XmlRssClientResponse($data, $client_encode, $this->rss_version);
        return $response;
    }

}

?>
